## UEFI Secure Boot Certificate Files For Development

| Certificate | Description                                        |
|-------------|----------------------------------------------------|
| pk.cer      | Platform key certificate. It consists of an X.509 self-signed. certificate in DER format. Must be installed in UEFI PK. |
| kek.cer     | Key Exchange Key certificate. It consists of an X.509 self-signed certificate in DER format. Must be installed in UEFI KEK. |
| db.cer      | Signature Database X.509 self-signed certificate in DER format for EFI Capsules authentication. Must be installed in UEFI db. |
| db.pem      | Signature Database X.509 self-signed certificate in PEM format. Required for 'sbsign' signing of EFI binaries. |

You can generate sample self-signed X.509 certificates with `openssl`.

To generate X.509 certificate signed with 2048-bit RSA key:

```sh
openssl req -newkey rsa:2048 -nodes -keyout Test.key \
    -new -x509 -sha256 -days 3650 -subj "/CN=Test Key/" \
    -outform PEM -out Test.pem
```

To generate X.509 certificate signed with 384-bit EC key:

```sh
openssl ecparam -name secp384r1 -genkey -noout -out Test.key
openssl req -new -x509 -sha384 -days 3650 -subj "/CN=Test Key/" \
    -key Test.key -outform PEM -out Test.pem
```

You can convert the X.509 self-signed certificate to DER format:

```sh
openssl x509 -inform PEM -outform DER -in Test.pem -out Test.cer
```

>>>
For testing purposes, self-signed X.509 certificate chain might be
generated with `uefi/test/mlx-mkkeys`.
>>>

You can find details on how to generate sample self-signed certificate
chain and sign data with PKC7 structure [here](https://github.com/tianocore/edk2/blob/master/BaseTools/Source/Python/Pkcs7Sign/Readme.md).

## Copyright

Copyright (c) 2022 NVIDIA Corporation. All rights reserved.